import { BaseSDK } from './sdk';
import { StandardResponse, Storage } from '@jolibox/types';

export class StorageSDK extends BaseSDK implements Storage {
  async getItem(key: string) {
    const result = await this.commands.executeCommand('StorageSDK.getItem', key);
    return result;
  }

  async setItem(key: string, value: number | string | boolean): Promise<StandardResponse<void>> {
    if (key.length > 128) {
      return {
        code: 'PARAMETER_ERROR',
        message: '[SDK] cloud storage setItem error: length of key should be less than 128'
      };
    }

    const valueToStore = typeof value == 'string' ? value : String(value);
    if (key.length + valueToStore.length > 1024) {
      return {
        code: 'PARAMETER_ERROR',
        message: '[SDK] cloud storage setItem error: length of key and value should be less than 1024'
      };
    }
    return await this.commands.executeCommand('StorageSDK.setItem', key, value);
  }

  async removeItem(key: string) {
    return this.commands.executeCommand('StorageSDK.removeItem', key);
  }

  async clear() {
    return this.commands.executeCommand('StorageSDK.clear');
  }
}
